@@ -4,8 +4,11 @@ package Padre::DB;
 
 use strict;
 use Padre;
-use ORLite Padre->ide->config_db;
+use ORLite 0.13 {
+	file   => Padre->ide->config_db,
+	tables => 0,
+};
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 1;
